%global srcname Werkzeug
%global modname werkzeug

Name:           python3-%{modname}
Version:        1.0.1
Release:        2%{?dist}
Summary:        Comprehensive WSGI web application library

License:        BSD
URL:            https://werkzeug.palletsprojects.com
Source0:        %{pypi_source}

# CVE-2023-25577
# https://github.com/pallets/werkzeug/security/advisories/GHSA-xg9f-g7g7-2323
# https://github.com/pallets/werkzeug/commit/fe899d0cdf767a7289a8bf746b7f72c2907a1b4b
Patch1:         0001-limit-the-maximum-number-of-multipart-form-parts.patch

# CVE-2023-23934
# https://github.com/pallets/werkzeug/security/advisories/GHSA-px8h-6qxv-m22q
# https://github.com/pallets/werkzeug/commit/8c2b4b82d0cade0d37e6a88e2cd2413878e8ebd4
Patch2:         0002-don-t-strip-leading-when-parsing-cookie.patch

# downstream-only patch for compatibility with pytest 2.9.2 in EPEL 7
Patch3:         0003-Remove-pytest.param-and-tmp_path-usage.patch

BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-pytest
BuildRequires:  python3-requests

%{?python_provide:%python_provide python3-%{modname}}


%description
Werkzeug
========

Werkzeug started as simple collection of various utilities for WSGI
applications and has become one of the most advanced WSGI utility
modules.  It includes a powerful debugger, full featured request and
response objects, HTTP utilities to handle entity tags, cache control
headers, HTTP dates, cookie handling, file uploads, a powerful URL
routing system and a bunch of community contributed addon modules.

Werkzeug is unicode aware and doesn't enforce a specific template
engine, database adapter or anything else.  It doesn't even enforce
a specific way of handling requests and leaves all that up to the
developer. It's most useful for end user applications which should work
on as many server environments as possible (such as blogs, wikis,
bulletin boards, etc.).


%prep
%autosetup -n %{srcname}-%{version} -p 1
rm -rf %{eggname}.egg-info


%build
%py3_build


%install
%py3_install


%check
export LANG=en_US.UTF-8
export PYTHONPATH=%{buildroot}%{python3_sitelib}
py.test-%{python3_version} --verbose


%files
%license LICENSE.rst
%doc CHANGES.rst README.rst
%{python3_sitelib}/%{srcname}-*.egg-info/
%{python3_sitelib}/%{modname}/


%changelog
* Mon Aug 28 2023 Carl George <carlwgeorge@fedoraproject.org> - 1.0.1-2
- Rename python36-werkzeug to python3-werkzeug
- Backport patch for CVE-2023-25577, resolves rhbz#2170246
- Backport patch for CVE-2023-23934, resolves rhbz#2170247
- Run test suite in %%check

* Wed Apr 08 2020 Igor Raits <ignatenkobrain@fedoraproject.org> - 1.0.1-1
- Initial package
